--[[

Copyright (C) 2010 Andre Leiradella

This software is provided 'as-is', without any express or implied
warranty. In no event will the authors be held liable for any damages
arising from the use of this software.

Permission is granted to anyone to use this software for any purpose,
including commercial applications, and to alter it and redistribute it
freely, subject to the following restrictions:

1. The origin of this software must not be misrepresented; you must not
claim that you wrote the original software. If you use this software
in a product, an acknowledgment in the product documentation would be
appreciated but is not required.

2. Altered source versions must be plainly marked as such, and must not be
misrepresented as being the original software.

3. This notice may not be removed or altered from any source
distribution.

-------------------------------------------------------------------------------

CHANGELOG

tigrs-1.2

* Now uses an image with the text for the ratings because it provides a better
  rendering than the engine.
* All images have dimensions of a power of two.
* Made configuration setup inside the tigrs table (avoids "tigrs." all over
  it.)
* Round down coordinates to avoid blurring the image.

tigrs-1.1

* Now uses LVE's built-in font.
* The rating configuration is now embededd in the tigrs.lua file.
* Got rid of "require" to release memory when the rating is no longer used.

tigrs-1.0

* First public release.

-------------------------------------------------------------------------------

INSTRUCTIONS

Unpack tigrs/* onto your game's root folder.

Edit the comments below to suit your needs, leaving exactly one line
uncommented in each section. To generate the rating box, write:

	tigrs = love.filesystem.load( 'tigrs/tigrs.lua' )()

To draw the logo, write:

  tigrs:draw( x, y )

If x is nil, the logo is horizontally centered. If y is nil, the logo is
vertically centered.

The TIGRS (TM) name, logo, and ratings are trademarks of Daniel Kinney.

DO NOT CHANGE THE SHORT DESCRIPTIONS. DOING SO WILL VOID YOUR RIGHT TO USE THE
TIGRS (TM) RATING LOGO. SEE http://www.tigrs.org/?page=specs

]]

local tigrs =
{

-- EDIT AFTER THIS LINE -------------------------------------------------------

------------
-- Rating --
------------

-- rating = 'Family friendly',
-- rating = 'Teen content',
rating = 'Adult content',

--------------
-- Violence --
--------------

-- Cartoon Violence

-- cartoon_violence = nil, -- None
-- cartoon_violence = 'Mild Cartoon Violence', -- Depictions of cartoon-like characters in unsafe situations
-- cartoon_violence = 'Cartoon Violence', -- Depictions of cartoon-like characters in aggressive conflict
cartoon_violence = 'Intense Cartoon Violence', -- Graphic depictions of violence involving cartoon-like characters

-- Fantasy Violence

-- fantasy_violence = nil, -- None
-- fantasy_violence = 'Mild Fantasy Violence', -- Depictions of characters in unsafe situations easily distinguishable from real life
-- fantasy_violence = 'Fantasy Violence', -- Depictions of characters in aggressive conflict easily distinguishable from real life
fantasy_violence = 'Intense Fantasy Violence', -- Graphic depictions of violence involving situations easily distinguishable from real life

-- Realistic Violence

-- realistic_violence = nil, -- None
-- realistic_violence = 'Mild Realistic Violence', -- Mild depictions of realistic characters in unsafe situations
-- realistic_violence = 'Realistic Violence', -- Depictions of realistic characters in aggressive conflict
realistic_violence = 'Intense Realistic Violence', -- Graphic depictions of violence involving realistic characters

-- Bloodshed

-- bloodshed = nil, -- None
-- bloodshed = 'Animated Bloodshed', -- Unrealistic depictions of bloodshed
-- bloodshed = 'Realistic Bloodshed', -- Realistic depictions of bloodshed
bloodshed = 'Blood and Gore', -- Depictions of bloodshed and the mutilation of body parts

-- Sexual Violence

-- sexual_violence = nil, -- None
sexual_violence = 'Sexual Violence', -- Depictions of or graphic references to rape or other violent sexual behavior

-------------------
-- Alcohol/Drugs --
-------------------

-- Alcohol

-- alcohol = nil, -- None
-- alcohol = 'Alcohol Reference', -- References to or images of alcoholic beverages
alcohol = 'Alcohol Use', -- Use of alcoholic beverages

-- Drugs

-- drugs = nil, -- None
-- drugs = 'Drug Reference', -- References to or images of illicit drugs
drugs = 'Drug Use', -- Use of illicit drugs

-- Tobacco

-- tobacco = nil, -- None
-- tobacco = 'Tobacco Reference', -- References to or images of tobacco products
tobacco = 'Tobacco Use', -- Use of tobacco products

----------------
-- Sex/Nudity --
----------------

-- Nudity

-- nudity = nil, -- None
-- nudity = 'Brief Nudity', -- Brief depictions of nudity or artistic nudity
nudity = 'Nudity', -- Prolonged depictions of nudity

-- Sexual Themes

-- sexual_themes = nil, -- None
-- sexual_themes = 'Suggestive Themes', -- Provocative references or depictions
-- sexual_themes = 'Sexual Themes', -- Sexual references or depictions
sexual_themes = 'Strong Sexual Content', -- Graphic depictions of sexual behavior

-- Sexual Violence

-- sexual_violence = nil, -- None
sexual_violence = 'Sexual Violence', -- Depictions of or graphic references to rape or other violent sexual behavior

-------------------
-- Miscellaneous --
-------------------

-- Language

-- language = nil, -- None
-- language = 'Mild Language', -- Mild or infrequent use of profanity
-- language = 'Moderate Language', -- Moderate use of profanity
language = 'Strong Language', -- Strong or frequent use of profanity

-- Humor

-- humor = nil, -- None
-- humor = 'Comical Shenanigans', -- Depictions of or dialog including slapstick humor
-- humor = 'Crass Humor', -- Depictions of or dialog including vulgar humor; bathroom humor
humor = 'Mature Humor', -- Depictions of or dialog including mature humor; sexual humor

-- Gambling

-- gambling = nil, -- None
-- gambling = 'Simulated Gambling', -- Player can gamble using "play" money
gambling = 'Real Gambling', -- Player can gamble using real money

-- DO NOT EDIT BELOW THIS LINE ------------------------------------------------

}

local quads = {}

quads[ 'Mild Cartoon Violence' ]      = {  0, 149 }
quads[ 'Cartoon Violence' ]           = {  1, 116 }
quads[ 'Intense Cartoon Violence' ]   = {  2, 171 }
quads[ 'Mild Fantasy Violence' ]      = {  3, 149 }
quads[ 'Fantasy Violence' ]           = {  4, 116 }
quads[ 'Intense Fantasy Violence' ]   = {  5, 171 }
quads[ 'Mild Realistic Violence' ]    = {  6, 153 }
quads[ 'Realistic Violence' ]         = {  7, 120 }
quads[ 'Intense Realistic Violence' ] = {  8, 175 }
quads[ 'Animated Bloodshed' ]         = {  9, 141 }
quads[ 'Realistic Bloodshed' ]        = { 10, 134 }
quads[ 'Blood and Gore' ]             = { 11, 105 }
quads[ 'Sexual Violence' ]            = { 12, 108 }
quads[ 'Alcohol Reference' ]          = { 13, 123 }
quads[ 'Alcohol Use' ]                = { 14,  80 }
quads[ 'Drug Reference' ]             = { 15, 107 }
quads[ 'Drug Use' ]                   = { 16,  63 }
quads[ 'Tobacco Reference' ]          = { 17, 129 }
quads[ 'Tobacco Use' ]                = { 18,  86 }
quads[ 'Brief Nudity' ]               = { 19,  83 }
quads[ 'Nudity' ]                     = { 20,  46 }
quads[ 'Suggestive Themes' ]          = { 21, 133 }
quads[ 'Sexual Themes' ]              = { 22, 103 }
quads[ 'Strong Sexual Content' ]      = { 23, 155 }
quads[ 'Sexual Violence' ]            = { 24, 108 }
quads[ 'Mild Language' ]              = { 25, 100 }
quads[ 'Moderate Language' ]          = { 26, 136 }
quads[ 'Strong Language' ]            = { 27, 117 }
quads[ 'Comical Shenanigans' ]        = { 28, 145 }
quads[ 'Crass Humor' ]                = { 29,  89 }
quads[ 'Mature Humor' ]               = { 30, 100 }
quads[ 'Simulated Gambling' ]         = { 31, 138 }
quads[ 'Real Gambling' ]              = { 32,  99 }

-- Rating.
if tigrs.rating == 'Family friendly' then
	tigrs.rating = love.graphics.newImage( 'tigrs/tigrs-horizontal-family-crystal.png' )
elseif tigrs.rating == 'Teen content' then
	tigrs.rating = love.graphics.newImage( 'tigrs/tigrs-horizontal-teen-crystal.png' )
else -- if tigrs.rating == 'Adult content' then
	tigrs.rating = love.graphics.newImage( 'tigrs/tigrs-horizontal-adult-crystal.png' )
end

-- Cartoon violence.
if tigrs.cartoon_violence then
	tigrs[ #tigrs + 1 ] = tigrs.cartoon_violence
end

-- Fantasy Violence
if tigrs.fantasy_violence then
	tigrs[ #tigrs + 1 ] = tigrs.fantasy_violence
end

-- Realistic Violence
if tigrs.realistic_violence then
	tigrs[ #tigrs + 1 ] = tigrs.realistic_violence
end

-- Bloodshed
if tigrs.bloodshed then
	tigrs[ #tigrs + 1 ] = tigrs.bloodshed
end

-- Sexual Violence
if tigrs.sexual_violence then
	tigrs[ #tigrs + 1 ] = tigrs.sexual_violence
end

-- Alcohol
if tigrs.alcohol then
	tigrs[ #tigrs + 1 ] = tigrs.alcohol
end

-- Drugs
if tigrs.drugs then
	tigrs[ #tigrs + 1 ] = tigrs.drugs
end

-- Tobacco
if tigrs.tobacco then
	tigrs[ #tigrs + 1 ] = tigrs.tobacco
end

-- Nudity
if tigrs.nudity then
	tigrs[ #tigrs + 1 ] = tigrs.nudity
end

-- Sexual Themes
if tigrs.sexual_themes then
	tigrs[ #tigrs + 1 ] = tigrs.sexual_themes
end

-- Sexual Violence
if tigrs.sexual_violence then
	tigrs[ #tigrs + 1 ] = tigrs.sexual_violence
end

-- Language
if tigrs.language then
	tigrs[ #tigrs + 1 ] = tigrs.language
end

-- Humor
if tigrs.humor then
	tigrs[ #tigrs + 1 ] = tigrs.humor
end

-- Gambling
if tigrs.gambling then
	tigrs[ #tigrs + 1 ] = tigrs.gambling
end

local text_width = 0, 0

-- Had to make these contants to avoid PO2 problems...
local image_width  = 120
local image_height = 200

for _, text in ipairs( tigrs ) do
	local width = quads[ text ][2]
	
	if width > text_width then
		text_width = width
	end
end

tigrs.font        = font
tigrs.text_width  = text_width
tigrs.line_height = 14
tigrs.width       = ( #tigrs ~= 0 ) and ( text_width + image_width + 16 ) or ( image_width )
tigrs.height      = image_height
tigrs.text        = love.graphics.newImage( 'tigrs/rating-texts.png' )

function tigrs:draw( x0, y0 )
	-- Center x.
	if not x0 then
		x0 = math.floor( ( love.graphics.getWidth() - self.width ) / 2 )
	end
	-- Center y.
	if not y0 then
		y0 = math.floor( ( love.graphics.getHeight() - self.height ) / 2 )
	end
	
	if #tigrs ~= 0 then
		-- Draw the box white background.
		local box_left  = x0 + self.width - self.text_width - 26
		local box_width = self.text_width + 25
		love.graphics.setColor( 255, 255, 255 )
		love.graphics.rectangle( 'fill', box_left, y0, box_width, self.height )
		
		-- Draw the box borders.
		love.graphics.setColor( 0, 0, 0 )
		love.graphics.rectangle( 'fill', box_left, y0, box_width, 6 )
		love.graphics.rectangle( 'fill', box_left, y0 + self.height - 6, box_width, 6 )
		love.graphics.rectangle( 'fill', x0 + self.width - 6, y0, 6, self.height )
	end
	
	-- Draw the rating logo.
	love.graphics.setColor( 255, 255, 255 )
	love.graphics.draw( self.rating, x0, y0 )
	
	-- Draw the text.
	x0 = x0 + image_width + 5
	local y = y0 + 10
	local line_height = self.line_height
	local quad = love.graphics.newQuad( 0, 0, 0, 0, 256, 512 )
	for _, text in ipairs( self ) do
		local quad_info = quads[ text ]
		quad:setViewport( 0, quad_info[1] * line_height, quad_info[2], line_height )
		love.graphics.drawq( tigrs.text, quad, x0, y )
		y = y + line_height
	end
end

return tigrs
